.. _iterative-sampling-label:

Random Sampling Search Algorithm
=================================

.. automodule:: MTfit.algorithms.monte_carlo

-------------------

.. autoclass:: MTfit.algorithms.monte_carlo.IterationSample
   :members:   
   :inherited-members:

-------------------
.. autoclass:: MTfit.algorithms.monte_carlo.TimeSample

   :members:
   :inherited-members:

-------------------

The random sampling algorithms inherit from the :class:`BaseAlgorithm` class:

.. autoclass:: MTfit.algorithms.base.BaseAlgorithm
   :members:

-------------------

They also inherit from the :class:`BaseMonteCarloRandomSample` class:

.. autoclass:: MTfit.algorithms.monte_carlo.BaseMonteCarloRandomSample
   :members:
